@@ -14,10 +14,6 @@ from .client import RelayClient
 from .hooks import HooksInstaller
 
 
-# Relay server configuration for response polling
-RELAY_URL = "https://relay.vgbndg.net"
-
-
 def install_scripts() -> dict:
     """Install hook scripts to ~/.watchcode/ directory.
 
@@ -97,12 +93,13 @@ def install_scripts() -> dict:
     return result
 
 
-def poll_for_response(auth_token: str, notification_id: str, timeout: int = 55) -> Optional[dict]:
+def poll_for_response(auth_token: str, notification_id: str, relay_url: str, timeout: int = 55) -> Optional[dict]:
     """Poll relay server for Watch response.
 
     Args:
         auth_token: The WatchCode auth token
         notification_id: The notification ID to poll for
+        relay_url: The relay server URL (from config)
         timeout: Maximum time to wait in seconds
 
     Returns:
@@ -110,7 +107,7 @@ def poll_for_response(auth_token: str, notification_id: str, timeout: int = 55)
     """
     import httpx
 
-    url = f"{RELAY_URL}/response/{auth_token}/{notification_id}"
+    url = f"{relay_url}/response/{auth_token}/{notification_id}"
     start_time = time.time()
     poll_count = 0
 
@@ -376,8 +373,8 @@ def test(no_wait: bool):
             click.echo("Test notification sent!")
             click.echo("Waiting for response (55s timeout)...")
 
-            # Poll for response
-            watch_response = poll_for_response(auth_token, notification_id, timeout=55)
+            # Poll for response using configured relay URL
+            watch_response = poll_for_response(auth_token, notification_id, config.get_relay_url(), timeout=55)
 
             if watch_response:
                 action = watch_response.get('action', 'unknown')
